#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .uid import uid as uid_cls
from .options_6 import options as options_cls
from .filter_settings import filter_settings as filter_settings_cls
from .range import range as range_cls
from .style_attribute_1 import style_attribute as style_attribute_cls
from .vector_settings import vector_settings as vector_settings_cls
from .plot import plot as plot_cls
from .track_single_particle_stream import track_single_particle_stream as track_single_particle_stream_cls
from .skip import skip as skip_cls
from .coarsen import coarsen as coarsen_cls
from .field import field as field_cls
from .injections_list import injections_list as injections_list_cls
from .free_stream_particles import free_stream_particles as free_stream_particles_cls
from .wall_film_particles import wall_film_particles as wall_film_particles_cls
from .track_pdf_particles import track_pdf_particles as track_pdf_particles_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .display_1 import display as display_cls
class particle_tracks_child(Group):
    """
    'child_object_type' of particle_tracks.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'filter_settings', 'range',
         'style_attribute', 'vector_settings', 'plot',
         'track_single_particle_stream', 'skip', 'coarsen', 'field',
         'injections_list', 'free_stream_particles', 'wall_film_particles',
         'track_pdf_particles', 'color_map', 'draw_mesh', 'mesh_object',
         'display_state_name']

    name: name_cls = name_cls
    """
    name child of particle_tracks_child.
    """
    uid: uid_cls = uid_cls
    """
    uid child of particle_tracks_child.
    """
    options: options_cls = options_cls
    """
    options child of particle_tracks_child.
    """
    filter_settings: filter_settings_cls = filter_settings_cls
    """
    filter_settings child of particle_tracks_child.
    """
    range: range_cls = range_cls
    """
    range child of particle_tracks_child.
    """
    style_attribute: style_attribute_cls = style_attribute_cls
    """
    style_attribute child of particle_tracks_child.
    """
    vector_settings: vector_settings_cls = vector_settings_cls
    """
    vector_settings child of particle_tracks_child.
    """
    plot: plot_cls = plot_cls
    """
    plot child of particle_tracks_child.
    """
    track_single_particle_stream: track_single_particle_stream_cls = track_single_particle_stream_cls
    """
    track_single_particle_stream child of particle_tracks_child.
    """
    skip: skip_cls = skip_cls
    """
    skip child of particle_tracks_child.
    """
    coarsen: coarsen_cls = coarsen_cls
    """
    coarsen child of particle_tracks_child.
    """
    field: field_cls = field_cls
    """
    field child of particle_tracks_child.
    """
    injections_list: injections_list_cls = injections_list_cls
    """
    injections_list child of particle_tracks_child.
    """
    free_stream_particles: free_stream_particles_cls = free_stream_particles_cls
    """
    free_stream_particles child of particle_tracks_child.
    """
    wall_film_particles: wall_film_particles_cls = wall_film_particles_cls
    """
    wall_film_particles child of particle_tracks_child.
    """
    track_pdf_particles: track_pdf_particles_cls = track_pdf_particles_cls
    """
    track_pdf_particles child of particle_tracks_child.
    """
    color_map: color_map_cls = color_map_cls
    """
    color_map child of particle_tracks_child.
    """
    draw_mesh: draw_mesh_cls = draw_mesh_cls
    """
    draw_mesh child of particle_tracks_child.
    """
    mesh_object: mesh_object_cls = mesh_object_cls
    """
    mesh_object child of particle_tracks_child.
    """
    display_state_name: display_state_name_cls = display_state_name_cls
    """
    display_state_name child of particle_tracks_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of particle_tracks_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .all_len_modified import all_len_modified as all_len_modified_cls
from .des_limiter_option import des_limiter_option as des_limiter_option_cls
class des_options(Group):
    """
    'des_options' child.
    """

    fluent_name = "des-options"

    child_names = \
        ['all_len_modified', 'des_limiter_option']

    all_len_modified: all_len_modified_cls = all_len_modified_cls
    """
    all_len_modified child of des_options.
    """
    des_limiter_option: des_limiter_option_cls = des_limiter_option_cls
    """
    des_limiter_option child of des_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .before_init_modification import before_init_modification as before_init_modification_cls
from .original_settings import original_settings as original_settings_cls
from .modifications import modifications as modifications_cls
class case_modification(Group):
    """
    'case_modification' child.
    """

    fluent_name = "case-modification"

    child_names = \
        ['before_init_modification', 'original_settings', 'modifications']

    before_init_modification: before_init_modification_cls = before_init_modification_cls
    """
    before_init_modification child of case_modification.
    """
    original_settings: original_settings_cls = original_settings_cls
    """
    original_settings child of case_modification.
    """
    modifications: modifications_cls = modifications_cls
    """
    modifications child of case_modification.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .edc_choice import edc_choice as edc_choice_cls
from .edc_constant_coefficient_options import edc_constant_coefficient_options as edc_constant_coefficient_options_cls
from .edc_pasr_model_options import edc_pasr_model_options as edc_pasr_model_options_cls
from .user_defined_edc_scales import user_defined_edc_scales as user_defined_edc_scales_cls
class edc_model_options(Group):
    """
    'edc_model_options' child.
    """

    fluent_name = "edc-model-options"

    child_names = \
        ['edc_choice', 'edc_constant_coefficient_options',
         'edc_pasr_model_options', 'user_defined_edc_scales']

    edc_choice: edc_choice_cls = edc_choice_cls
    """
    edc_choice child of edc_model_options.
    """
    edc_constant_coefficient_options: edc_constant_coefficient_options_cls = edc_constant_coefficient_options_cls
    """
    edc_constant_coefficient_options child of edc_model_options.
    """
    edc_pasr_model_options: edc_pasr_model_options_cls = edc_pasr_model_options_cls
    """
    edc_pasr_model_options child of edc_model_options.
    """
    user_defined_edc_scales: user_defined_edc_scales_cls = user_defined_edc_scales_cls
    """
    user_defined_edc_scales child of edc_model_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .type_6 import type as type_cls
from .boundary_1 import boundary_1 as boundary_1_cls
from .boundary_2 import boundary_2 as boundary_2_cls
from .periodicity import periodicity as periodicity_cls
from .mesh_connectivity import mesh_connectivity as mesh_connectivity_cls
class interfaces_child(Group):
    """
    'child_object_type' of interfaces.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'type', 'boundary_1', 'boundary_2', 'periodicity',
         'mesh_connectivity']

    name: name_cls = name_cls
    """
    name child of interfaces_child.
    """
    type: type_cls = type_cls
    """
    type child of interfaces_child.
    """
    boundary_1: boundary_1_cls = boundary_1_cls
    """
    boundary_1 child of interfaces_child.
    """
    boundary_2: boundary_2_cls = boundary_2_cls
    """
    boundary_2 child of interfaces_child.
    """
    periodicity: periodicity_cls = periodicity_cls
    """
    periodicity child of interfaces_child.
    """
    mesh_connectivity: mesh_connectivity_cls = mesh_connectivity_cls
    """
    mesh_connectivity child of interfaces_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .database import database as database_cls
from .fluid import fluid as fluid_cls
from .solid import solid as solid_cls
from .mixture import mixture as mixture_cls
from .inert_particle import inert_particle as inert_particle_cls
from .droplet_particle import droplet_particle as droplet_particle_cls
from .combusting_particle import combusting_particle as combusting_particle_cls
from .particle_mixture import particle_mixture as particle_mixture_cls
from .list_materials_1 import list_materials as list_materials_cls
from .list_properties_3 import list_properties as list_properties_cls
class materials(Group):
    """
    'materials' child.
    """

    fluent_name = "materials"

    child_names = \
        ['database', 'fluid', 'solid', 'mixture', 'inert_particle',
         'droplet_particle', 'combusting_particle', 'particle_mixture']

    database: database_cls = database_cls
    """
    database child of materials.
    """
    fluid: fluid_cls = fluid_cls
    """
    fluid child of materials.
    """
    solid: solid_cls = solid_cls
    """
    solid child of materials.
    """
    mixture: mixture_cls = mixture_cls
    """
    mixture child of materials.
    """
    inert_particle: inert_particle_cls = inert_particle_cls
    """
    inert_particle child of materials.
    """
    droplet_particle: droplet_particle_cls = droplet_particle_cls
    """
    droplet_particle child of materials.
    """
    combusting_particle: combusting_particle_cls = combusting_particle_cls
    """
    combusting_particle child of materials.
    """
    particle_mixture: particle_mixture_cls = particle_mixture_cls
    """
    particle_mixture child of materials.
    """
    command_names = \
        ['list_materials', 'list_properties']

    list_materials: list_materials_cls = list_materials_cls
    """
    list_materials command of materials.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of materials.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_22 import enabled as enabled_cls
from .set_5 import set as set_cls
class conjugate_heat_transfer(Group):
    """
    Enter the conjugate heat transfer menu.
    """

    fluent_name = "conjugate-heat-transfer"

    child_names = \
        ['enabled', 'set']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of conjugate_heat_transfer.
    """
    set: set_cls = set_cls
    """
    set child of conjugate_heat_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class set_one_to_one_pairing_tolerance(Boolean):
    """
    Enable/disable one-to-one auto pairing tolerance.
    """

    fluent_name = "set-one-to-one-pairing-tolerance"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .domain_val import domain_val as domain_val_cls
class uds_flow(Command):
    """
    'uds_flow' command.
    
    Parameters
    ----------
        domain_val : str
            'domain_val' child.
    
    """

    fluent_name = "uds-flow"

    argument_names = \
        ['domain_val']

    domain_val: domain_val_cls = domain_val_cls
    """
    domain_val argument of uds_flow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_4 import method as method_cls
from .type_1 import type as type_cls
from .interval_1 import interval as interval_cls
from .frequency_1 import frequency as frequency_cls
class single_session_coupling(Group):
    """
    'single_session_coupling' child.
    """

    fluent_name = "single-session-coupling"

    child_names = \
        ['method', 'type', 'interval', 'frequency']

    method: method_cls = method_cls
    """
    method child of single_session_coupling.
    """
    type: type_cls = type_cls
    """
    type child of single_session_coupling.
    """
    interval: interval_cls = interval_cls
    """
    interval child of single_session_coupling.
    """
    frequency: frequency_cls = frequency_cls
    """
    frequency child of single_session_coupling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .set_units import set_units as set_units_cls
from .set_unit_system import set_unit_system as set_unit_system_cls
class units(Group):
    """
    'units' child.
    """

    fluent_name = "units"

    command_names = \
        ['set_units', 'set_unit_system']

    set_units: set_units_cls = set_units_cls
    """
    set_units command of units.
    """
    set_unit_system: set_unit_system_cls = set_unit_system_cls
    """
    set_unit_system command of units.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .none_1 import none as none_cls
from .gradient_1 import gradient as gradient_cls
from .curvature import curvature as curvature_cls
from .hessian import hessian as hessian_cls
class derivative(Group):
    """
    'derivative' child.
    """

    fluent_name = "derivative"

    child_names = \
        ['option', 'none', 'gradient', 'curvature', 'hessian']

    option: option_cls = option_cls
    """
    option child of derivative.
    """
    none: none_cls = none_cls
    """
    none child of derivative.
    """
    gradient: gradient_cls = gradient_cls
    """
    gradient child of derivative.
    """
    curvature: curvature_cls = curvature_cls
    """
    curvature child of derivative.
    """
    hessian: hessian_cls = hessian_cls
    """
    hessian child of derivative.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .relaxation import relaxation as relaxation_cls
from .flux import flux as flux_cls
from .gradient import gradient as gradient_cls
class anisotropic_solid_heat_transfer(Group):
    """
    Enter anisotropic solid heat transfer menu.
    """

    fluent_name = "anisotropic-solid-heat-transfer"

    child_names = \
        ['relaxation', 'flux', 'gradient']

    relaxation: relaxation_cls = relaxation_cls
    """
    relaxation child of anisotropic_solid_heat_transfer.
    """
    flux: flux_cls = flux_cls
    """
    flux child of anisotropic_solid_heat_transfer.
    """
    gradient: gradient_cls = gradient_cls
    """
    gradient child of anisotropic_solid_heat_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .rk2 import rk2 as rk2_cls
class fast_transient_settings(Group):
    """
    'fast_transient_settings' child.
    """

    fluent_name = "fast-transient-settings"

    child_names = \
        ['rk2']

    rk2: rk2_cls = rk2_cls
    """
    rk2 child of fast_transient_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .web_server import web_server as web_server_cls
class server(Group):
    """
    'server' child.
    """

    fluent_name = "server"

    child_names = \
        ['web_server']

    web_server: web_server_cls = web_server_cls
    """
    web_server child of server.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .old_props import old_props as old_props_cls
from .previous_values_to_consider import previous_values_to_consider as previous_values_to_consider_cls
from .initial_values_to_ignore import initial_values_to_ignore as initial_values_to_ignore_cls
from .iteration_at_creation_or_edit import iteration_at_creation_or_edit as iteration_at_creation_or_edit_cls
from .stop_criterion import stop_criterion as stop_criterion_cls
from .report_defs_1 import report_defs as report_defs_cls
from .print_1 import print as print_cls
from .plot import plot as plot_cls
from .cov import cov as cov_cls
from .active import active as active_cls
from .x_label import x_label as x_label_cls
from .previous_values import previous_values as previous_values_cls
class convergence_reports_child(Group):
    """
    'child_object_type' of convergence_reports.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'old_props', 'previous_values_to_consider',
         'initial_values_to_ignore', 'iteration_at_creation_or_edit',
         'stop_criterion', 'report_defs', 'print', 'plot', 'cov', 'active',
         'x_label', 'previous_values']

    name: name_cls = name_cls
    """
    name child of convergence_reports_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of convergence_reports_child.
    """
    previous_values_to_consider: previous_values_to_consider_cls = previous_values_to_consider_cls
    """
    previous_values_to_consider child of convergence_reports_child.
    """
    initial_values_to_ignore: initial_values_to_ignore_cls = initial_values_to_ignore_cls
    """
    initial_values_to_ignore child of convergence_reports_child.
    """
    iteration_at_creation_or_edit: iteration_at_creation_or_edit_cls = iteration_at_creation_or_edit_cls
    """
    iteration_at_creation_or_edit child of convergence_reports_child.
    """
    stop_criterion: stop_criterion_cls = stop_criterion_cls
    """
    stop_criterion child of convergence_reports_child.
    """
    report_defs: report_defs_cls = report_defs_cls
    """
    report_defs child of convergence_reports_child.
    """
    print: print_cls = print_cls
    """
    print child of convergence_reports_child.
    """
    plot: plot_cls = plot_cls
    """
    plot child of convergence_reports_child.
    """
    cov: cov_cls = cov_cls
    """
    cov child of convergence_reports_child.
    """
    active: active_cls = active_cls
    """
    active child of convergence_reports_child.
    """
    x_label: x_label_cls = x_label_cls
    """
    x_label child of convergence_reports_child.
    """
    previous_values: previous_values_cls = previous_values_cls
    """
    previous_values child of convergence_reports_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .ni import ni as ni_cls
from .nj import nj as nj_cls
from .nk import nk as nk_cls
from .xe import xe as xe_cls
from .len import len as len_cls
class beach_dir_list_child(Group):
    """
    'child_object_type' of beach_dir_list.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['ni', 'nj', 'nk', 'xe', 'len']

    ni: ni_cls = ni_cls
    """
    ni child of beach_dir_list_child.
    """
    nj: nj_cls = nj_cls
    """
    nj child of beach_dir_list_child.
    """
    nk: nk_cls = nk_cls
    """
    nk child of beach_dir_list_child.
    """
    xe: xe_cls = xe_cls
    """
    xe child of beach_dir_list_child.
    """
    len: len_cls = len_cls
    """
    len child of beach_dir_list_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .ecad_name import ecad_name as ecad_name_cls
from .choice import choice as choice_cls
from .rows import rows as rows_cls
from .columns import columns as columns_cls
from .ref_frame import ref_frame as ref_frame_cls
from .pwr_names import pwr_names as pwr_names_cls
class pcb_zone_info(Group):
    """
    'pcb_zone_info' child.
    """

    fluent_name = "pcb-zone-info"

    child_names = \
        ['ecad_name', 'choice', 'rows', 'columns', 'ref_frame', 'pwr_names']

    ecad_name: ecad_name_cls = ecad_name_cls
    """
    ecad_name child of pcb_zone_info.
    """
    choice: choice_cls = choice_cls
    """
    choice child of pcb_zone_info.
    """
    rows: rows_cls = rows_cls
    """
    rows child of pcb_zone_info.
    """
    columns: columns_cls = columns_cls
    """
    columns child of pcb_zone_info.
    """
    ref_frame: ref_frame_cls = ref_frame_cls
    """
    ref_frame child of pcb_zone_info.
    """
    pwr_names: pwr_names_cls = pwr_names_cls
    """
    pwr_names child of pcb_zone_info.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .axis_begin import axis_begin as axis_begin_cls
from .axis_end import axis_end as axis_end_cls
from .radius import radius as radius_cls
from .inside import inside as inside_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls
class cylinder(Group):
    """
    'cylinder' child.
    """

    fluent_name = "cylinder"

    child_names = \
        ['axis_begin', 'axis_end', 'radius', 'inside',
         'create_volume_surface']

    axis_begin: axis_begin_cls = axis_begin_cls
    """
    axis_begin child of cylinder.
    """
    axis_end: axis_end_cls = axis_end_cls
    """
    axis_end child of cylinder.
    """
    radius: radius_cls = radius_cls
    """
    radius child of cylinder.
    """
    inside: inside_cls = inside_cls
    """
    inside child of cylinder.
    """
    create_volume_surface: create_volume_surface_cls = create_volume_surface_cls
    """
    create_volume_surface child of cylinder.
    """



import pytest

from ansys.fluent.core import examples

import_file_name = examples.download_file(
    "elbow.cas.h5", "pyfluent/examples/DOE-ML-Mixing-Elbow"
)


@pytest.mark.fluent_version(">=23.2")
def test_meshing_queries(new_mesh_session):
    meshing_session = new_mesh_session
    meshing_session.tui.file.read_case(import_file_name)
    meshing_queries = meshing_session.meshing_queries

    assert meshing_queries.get_face_zone_at_location([1.4, 1.4, 1.4]) == 34
    assert meshing_queries.get_zones_of_type("velocity-inlet") == [30, 31]
    assert meshing_queries.get_zones_of_group("inlet") == [31, 30]
    assert meshing_queries.get_face_zones_of_filter("*") == [
        3462,
        34,
        33,
        32,
        31,
        30,
        29,
    ]
    assert meshing_queries.get_cell_zones_of_filter("*") == [3460]
    assert meshing_queries.get_edge_zones_of_filter("*") == []
    assert meshing_queries.get_node_zones_of_filter("*") == [3625, 3624]
    assert meshing_queries.get_objects_of_type("mesh") == ["elbow-fluid"]
    assert meshing_queries.get_face_zone_id_list_of_object("elbow-fluid") == [
        29,
        30,
        31,
        32,
        33,
        34,
    ]
    assert meshing_queries.get_edge_zone_id_list_of_object("elbow-fluid") == []

    assert meshing_queries.get_cell_zone_id_list_of_object("elbow-fluid") == [3460]
    assert (
        meshing_queries.get_face_zones_shared_by_regions_of_type(
            "elbow-fluid",
            "fluid-fluid",
        )
        == []
    )
    assert meshing_queries.get_face_zones_of_regions(
        "elbow-fluid",
        ["fluid"],
    ) == [34, 33, 32, 31, 30, 29]
    assert meshing_queries.get_face_zones_of_labels(
        "elbow-fluid",
        ["inlet", "outlet", "wall", "internal"],
    ) == [32]
    assert meshing_queries.get_face_zone_id_list_of_labels(
        "elbow-fluid",
        ["outlet"],
    ) == [32]
    assert meshing_queries.get_face_zones_of_objects(
        ["elbow-fluid"],
    ) == [29, 30, 31, 32, 33, 34]
    assert meshing_queries.get_edge_zones_of_objects(["elbow-fluid"]) == []
    assert meshing_queries.get_face_zone_id_list_of_regions(
        "elbow-fluid",
        ["fluid"],
    ) == [
        34,
        33,
        32,
        31,
        30,
        29,
    ]
    assert meshing_queries.get_prism_cell_zones(["inlet", "outlet"]) == []
    assert meshing_queries.get_prism_cell_zones("*") == []

    assert meshing_queries.get_tet_cell_zones(["inlet", "outlet"]) == []
    assert meshing_queries.get_tet_cell_zones("*") == []
    assert meshing_queries.get_adjacent_cell_zones([30]) == [3460]
    assert meshing_queries.get_adjacent_cell_zones("*") == [3460]
    assert meshing_queries.get_adjacent_face_zones([3460]) == [29, 30, 31, 32, 33, 34]
    assert meshing_queries.get_adjacent_face_zones("*") == [29, 30, 31, 32, 33, 34]
    assert meshing_queries.get_shared_boundary_zones("*") == []
    assert meshing_queries.get_shared_boundary_zones([3460]) == []
    face_zones = meshing_queries.get_adjacent_interior_and_boundary_face_zones
    assert face_zones([30]) == []
    assert face_zones("fluid") == [29, 30, 31, 32, 33, 34, 3462]

    assert face_zones("*") == [29, 30, 31, 32, 33, 34, 3462]
    assert meshing_queries.get_adjacent_zones_by_edge_connectivity([30]) == [33, 29]
    assert meshing_queries.get_adjacent_zones_by_edge_connectivity("*") == []
    assert meshing_queries.get_adjacent_zones_by_node_connectivity([30]) == [
        29,
        33,
    ]
    assert meshing_queries.get_adjacent_zones_by_node_connectivity("*") == []
    assert meshing_queries.get_interior_zones_connected_to_cell_zones([3460]) == [3462]
    assert meshing_queries.get_interior_zones_connected_to_cell_zones("*") == [3462]
    assert meshing_queries.get_face_zones_with_zone_specific_prisms_applied() == []
    assert meshing_queries.get_face_zones_of_prism_controls("*") == [
        33,
        34,
    ]
    assert meshing_queries.get_baffles([29, 30]) == [30, 29]

    assert meshing_queries.get_embedded_baffles() == []
    assert meshing_queries.get_wrapped_zones() == []
    assert meshing_queries.get_unreferenced_edge_zones() == []
    assert meshing_queries.get_unreferenced_face_zones() == []
    assert meshing_queries.get_unreferenced_cell_zones() == []
    assert meshing_queries.get_unreferenced_edge_zones_of_filter("*") == []
    assert meshing_queries.get_unreferenced_face_zones_of_filter("*") == []
    assert meshing_queries.get_unreferenced_cell_zones_of_filter("*") == []
    assert meshing_queries.get_unreferenced_edge_zone_id_list_of_pattern("*") == []
    assert meshing_queries.get_unreferenced_face_zone_id_list_of_pattern("*") == []

    assert meshing_queries.get_unreferenced_cell_zone_id_list_of_pattern("*") == []
    assert meshing_queries.get_maxsize_cell_zone_by_volume("*") == 3460
    assert meshing_queries.get_maxsize_cell_zone_by_volume([3460]) == 3460
    assert meshing_queries.get_maxsize_cell_zone_by_count("*") == 3460
    assert meshing_queries.get_maxsize_cell_zone_by_count([3460]) == 3460
    assert meshing_queries.get_minsize_face_zone_by_area("*") == 30
    assert meshing_queries.get_minsize_face_zone_by_area([29, 30, 31, 32, 33, 34]) == 30
    assert meshing_queries.get_minsize_face_zone_by_count("*") == 30
    assert (
        meshing_queries.get_minsize_face_zone_by_count([29, 30, 31, 32, 33, 34]) == 30
    )
    assert meshing_queries.get_face_zone_list_by_maximum_entity_count(20, True) == []

    assert meshing_queries.get_edge_zone_list_by_maximum_entity_count(20, False) == []
    assert meshing_queries.get_cell_zone_list_by_maximum_entity_count(1) == []
    assert meshing_queries.get_face_zone_list_by_maximum_zone_area(100) == [
        33,
        32,
        31,
        30,
    ]
    assert meshing_queries.get_face_zone_list_by_minimum_zone_area(10) == [
        34,
        29,
    ]
    assert meshing_queries.get_zones_with_free_faces("*") == []
    assert meshing_queries.get_zones_with_free_faces([29, 30, 31, 32]) == []
    assert meshing_queries.get_zones_with_free_faces(["inlet", "outlet"]) == []
    assert meshing_queries.get_zones_with_multi_faces("*") == []
    assert meshing_queries.get_zones_with_multi_faces([29, 30, 31, 32]) == []
    assert meshing_queries.get_zones_with_multi_faces(["inlet", "outlet"]) == []

    assert meshing_queries.get_overlapping_face_zones("*", 0.1, 0.1) == []
    assert meshing_queries.get_zones_with_marked_faces("*") == []
    assert meshing_queries.get_zones_with_marked_faces([29, 30, 31, 32]) == []
    assert meshing_queries.get_zones_with_marked_faces(["inlet", "outlet"]) == []
    assert meshing_queries.get_all_object_name_list() == ["elbow-fluid"]
    assert meshing_queries.get_object_name_list_of_type("mesh") == ["elbow-fluid"]
    assert meshing_queries.get_objects_of_filter("*") == ["elbow-fluid"]
    assert meshing_queries.get_regions_of_object("elbow-fluid") == ["fluid"]
    assert meshing_queries.get_region_name_list_of_object("elbow-fluid") == ["fluid"]
    assert (
        str(
            meshing_queries.sort_regions_by_volume(
                "elbow-fluid",
                "ascending",
            )
        )
        == '[volume: 152.599422561798\nregion: "fluid"\n]'
    )

    assert meshing_queries.get_region_volume("elbow-fluid", "fluid") == 152.599422561798
    assert meshing_queries.get_regions_of_filter("elbow-fluid", "*") == ["fluid"]
    assert meshing_queries.get_region_name_list_of_pattern("elbow-fluid", "*") == [
        "fluid"
    ]
    assert meshing_queries.get_regions_of_face_zones([29, 30, 31, 32, 33, 34]) == [
        "fluid"
    ]
    assert str(meshing_queries.find_join_pairs("outlet", 0.1, True, 40)) == "[]"
    assert str(meshing_queries.find_join_pairs([32], 0.1, True, 40)) == "[]"
    assert str(meshing_queries.find_join_pairs(["outlet"], 0.1, True, 40)) == "[]"
    assert meshing_queries.get_region_name_list_of_face_zones(
        [29, 30, 31, 32, 33, 34]
    ) == ["fluid"]



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .shell_script_path import shell_script_path as shell_script_path_cls
from .kill_all_nodes import kill_all_nodes as kill_all_nodes_cls
from .kill_node import kill_node as kill_node_cls
from .spawn_node import spawn_node as spawn_node_cls
from .load_hosts import load_hosts as load_hosts_cls
from .save_hosts import save_hosts as save_hosts_cls
class network(Group):
    """
    Enter the network configuration menu.
    """

    fluent_name = "network"

    child_names = \
        ['shell_script_path']

    shell_script_path: shell_script_path_cls = shell_script_path_cls
    """
    shell_script_path child of network.
    """
    command_names = \
        ['kill_all_nodes', 'kill_node', 'spawn_node', 'load_hosts',
         'save_hosts']

    kill_all_nodes: kill_all_nodes_cls = kill_all_nodes_cls
    """
    kill_all_nodes command of network.
    """
    kill_node: kill_node_cls = kill_node_cls
    """
    kill_node command of network.
    """
    spawn_node: spawn_node_cls = spawn_node_cls
    """
    spawn_node command of network.
    """
    load_hosts: load_hosts_cls = load_hosts_cls
    """
    load_hosts command of network.
    """
    save_hosts: save_hosts_cls = save_hosts_cls
    """
    save_hosts command of network.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .courant_number import courant_number as courant_number_cls
from .p_v_controls import p_v_controls as p_v_controls_cls
from .relaxation_factor_1 import relaxation_factor as relaxation_factor_cls
from .under_relaxation_2 import under_relaxation as under_relaxation_cls
from .pseudo_time_method_local_time_step import pseudo_time_method_local_time_step as pseudo_time_method_local_time_step_cls
from .pseudo_time_explicit_relaxation_factor import pseudo_time_explicit_relaxation_factor as pseudo_time_explicit_relaxation_factor_cls
from .acoustics_wave_eqn_controls import acoustics_wave_eqn_controls as acoustics_wave_eqn_controls_cls
from .contact_solution_controls import contact_solution_controls as contact_solution_controls_cls
from .equations import equations as equations_cls
from .limits import limits as limits_cls
from .advanced_2 import advanced as advanced_cls
from .reset_solution_controls import reset_solution_controls as reset_solution_controls_cls
from .reset_amg_controls import reset_amg_controls as reset_amg_controls_cls
from .reset_multi_stage_parameters import reset_multi_stage_parameters as reset_multi_stage_parameters_cls
from .reset_limits import reset_limits as reset_limits_cls
from .reset_pseudo_time_method_generic import reset_pseudo_time_method_generic as reset_pseudo_time_method_generic_cls
from .reset_pseudo_time_method_equations import reset_pseudo_time_method_equations as reset_pseudo_time_method_equations_cls
from .reset_pseudo_time_method_relaxations import reset_pseudo_time_method_relaxations as reset_pseudo_time_method_relaxations_cls
from .reset_pseudo_time_method_scale_factors import reset_pseudo_time_method_scale_factors as reset_pseudo_time_method_scale_factors_cls
class controls(Group):
    """
    Enter solution controls menu.
    """

    fluent_name = "controls"

    child_names = \
        ['courant_number', 'p_v_controls', 'relaxation_factor',
         'under_relaxation', 'pseudo_time_method_local_time_step',
         'pseudo_time_explicit_relaxation_factor',
         'acoustics_wave_eqn_controls', 'contact_solution_controls',
         'equations', 'limits', 'advanced']

    courant_number: courant_number_cls = courant_number_cls
    """
    courant_number child of controls.
    """
    p_v_controls: p_v_controls_cls = p_v_controls_cls
    """
    p_v_controls child of controls.
    """
    relaxation_factor: relaxation_factor_cls = relaxation_factor_cls
    """
    relaxation_factor child of controls.
    """
    under_relaxation: under_relaxation_cls = under_relaxation_cls
    """
    under_relaxation child of controls.
    """
    pseudo_time_method_local_time_step: pseudo_time_method_local_time_step_cls = pseudo_time_method_local_time_step_cls
    """
    pseudo_time_method_local_time_step child of controls.
    """
    pseudo_time_explicit_relaxation_factor: pseudo_time_explicit_relaxation_factor_cls = pseudo_time_explicit_relaxation_factor_cls
    """
    pseudo_time_explicit_relaxation_factor child of controls.
    """
    acoustics_wave_eqn_controls: acoustics_wave_eqn_controls_cls = acoustics_wave_eqn_controls_cls
    """
    acoustics_wave_eqn_controls child of controls.
    """
    contact_solution_controls: contact_solution_controls_cls = contact_solution_controls_cls
    """
    contact_solution_controls child of controls.
    """
    equations: equations_cls = equations_cls
    """
    equations child of controls.
    """
    limits: limits_cls = limits_cls
    """
    limits child of controls.
    """
    advanced: advanced_cls = advanced_cls
    """
    advanced child of controls.
    """
    command_names = \
        ['reset_solution_controls', 'reset_amg_controls',
         'reset_multi_stage_parameters', 'reset_limits',
         'reset_pseudo_time_method_generic',
         'reset_pseudo_time_method_equations',
         'reset_pseudo_time_method_relaxations',
         'reset_pseudo_time_method_scale_factors']

    reset_solution_controls: reset_solution_controls_cls = reset_solution_controls_cls
    """
    reset_solution_controls command of controls.
    """
    reset_amg_controls: reset_amg_controls_cls = reset_amg_controls_cls
    """
    reset_amg_controls command of controls.
    """
    reset_multi_stage_parameters: reset_multi_stage_parameters_cls = reset_multi_stage_parameters_cls
    """
    reset_multi_stage_parameters command of controls.
    """
    reset_limits: reset_limits_cls = reset_limits_cls
    """
    reset_limits command of controls.
    """
    reset_pseudo_time_method_generic: reset_pseudo_time_method_generic_cls = reset_pseudo_time_method_generic_cls
    """
    reset_pseudo_time_method_generic command of controls.
    """
    reset_pseudo_time_method_equations: reset_pseudo_time_method_equations_cls = reset_pseudo_time_method_equations_cls
    """
    reset_pseudo_time_method_equations command of controls.
    """
    reset_pseudo_time_method_relaxations: reset_pseudo_time_method_relaxations_cls = reset_pseudo_time_method_relaxations_cls
    """
    reset_pseudo_time_method_relaxations command of controls.
    """
    reset_pseudo_time_method_scale_factors: reset_pseudo_time_method_scale_factors_cls = reset_pseudo_time_method_scale_factors_cls
    """
    reset_pseudo_time_method_scale_factors command of controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class patch:
    fluent_name = ...
    child_names = ...
    vof_smooth_options = ...
    command_names = ...

    def calculate_patch(self, domain: str, cell_zones: List[str], register_id: List[str], variable: str, patch_velocity: bool, use_custom_field_function: bool, custom_field_function_name: str, value: Union[float, str]):
        """
        Patch a value for a flow variable in the domain.
        
        Parameters
        ----------
            domain : str
                'domain' child.
            cell_zones : typing.List[str]
                'cell_zones' child.
            register_id : typing.List[str]
                'register_id' child.
            variable : str
                'variable' child.
            patch_velocity : bool
                'patch_velocity' child.
            use_custom_field_function : bool
                'use_custom_field_function' child.
            custom_field_function_name : str
                'custom_field_function_name' child.
            value : real
                'value' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .filename import filename as filename_cls
from .unit import unit as unit_cls
class read(Command):
    """
    Read surface meshes.
    
    Parameters
    ----------
        filename : str
            'filename' child.
        unit : str
            'unit' child.
    
    """

    fluent_name = "read"

    argument_names = \
        ['filename', 'unit']

    filename: filename_cls = filename_cls
    """
    filename argument of read.
    """
    unit: unit_cls = unit_cls
    """
    unit argument of read.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .formulation import formulation as formulation_cls
from .relaxation_method_1 import relaxation_method as relaxation_method_cls
from .convergence_acceleration_for_stretched_meshes_1 import convergence_acceleration_for_stretched_meshes as convergence_acceleration_for_stretched_meshes_cls
from .relaxation_bounds import relaxation_bounds as relaxation_bounds_cls
class pseudo_time_method(Group):
    """
    Enter the pseudo time method menu.
    """

    fluent_name = "pseudo-time-method"

    child_names = \
        ['formulation', 'relaxation_method',
         'convergence_acceleration_for_stretched_meshes']

    formulation: formulation_cls = formulation_cls
    """
    formulation child of pseudo_time_method.
    """
    relaxation_method: relaxation_method_cls = relaxation_method_cls
    """
    relaxation_method child of pseudo_time_method.
    """
    convergence_acceleration_for_stretched_meshes: convergence_acceleration_for_stretched_meshes_cls = convergence_acceleration_for_stretched_meshes_cls
    """
    convergence_acceleration_for_stretched_meshes child of pseudo_time_method.
    """
    command_names = \
        ['relaxation_bounds']

    relaxation_bounds: relaxation_bounds_cls = relaxation_bounds_cls
    """
    relaxation_bounds command of pseudo_time_method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .vof_min_seeding import vof_min_seeding as vof_min_seeding_cls
from .ia_grad_sym import ia_grad_sym as ia_grad_sym_cls
class area_density(Group):
    """
    Interfacial area density menu.
    """

    fluent_name = "area-density"

    child_names = \
        ['vof_min_seeding', 'ia_grad_sym']

    vof_min_seeding: vof_min_seeding_cls = vof_min_seeding_cls
    """
    vof_min_seeding child of area_density.
    """
    ia_grad_sym: ia_grad_sym_cls = ia_grad_sym_cls
    """
    ia_grad_sym child of area_density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class high_order_pressure(Boolean):
    """
    High order pressure extrapolation at overset interface.
    """

    fluent_name = "high-order-pressure?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fixed_periodic import fixed_periodic as fixed_periodic_cls
from .fixed_periodic_type import fixed_periodic_type as fixed_periodic_type_cls
from .fixed_periodic_type_value import fixed_periodic_type_value as fixed_periodic_type_value_cls
from .times_step_periods import times_step_periods as times_step_periods_cls
from .total_period_run import total_period_run as total_period_run_cls
class fixed_periodic(Group):
    """
    'fixed_periodic' child.
    """

    fluent_name = "fixed-periodic"

    child_names = \
        ['fixed_periodic', 'fixed_periodic_type', 'fixed_periodic_type_value',
         'times_step_periods', 'total_period_run']

    fixed_periodic: fixed_periodic_cls = fixed_periodic_cls
    """
    fixed_periodic child of fixed_periodic.
    """
    fixed_periodic_type: fixed_periodic_type_cls = fixed_periodic_type_cls
    """
    fixed_periodic_type child of fixed_periodic.
    """
    fixed_periodic_type_value: fixed_periodic_type_value_cls = fixed_periodic_type_value_cls
    """
    fixed_periodic_type_value child of fixed_periodic.
    """
    times_step_periods: times_step_periods_cls = times_step_periods_cls
    """
    times_step_periods child of fixed_periodic.
    """
    total_period_run: total_period_run_cls = total_period_run_cls
    """
    total_period_run child of fixed_periodic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_3 import zone_name as zone_name_cls
from .domain import domain as domain_cls
from .new_phase import new_phase as new_phase_cls
class change_zone_state(Command):
    """
    Change the realgas material state for a zone.
    
    Parameters
    ----------
        zone_name : str
            Enter a fluid zone name.
        domain : str
            'domain' child.
        new_phase : int
            'new_phase' child.
    
    """

    fluent_name = "change-zone-state"

    argument_names = \
        ['zone_name', 'domain', 'new_phase']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of change_zone_state.
    """
    domain: domain_cls = domain_cls
    """
    domain argument of change_zone_state.
    """
    new_phase: new_phase_cls = new_phase_cls
    """
    new_phase argument of change_zone_state.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class materials:
    fluent_name = ...
    child_names = ...
    database = ...
    fluid = ...
    solid = ...
    mixture = ...
    inert_particle = ...
    droplet_particle = ...
    combusting_particle = ...
    particle_mixture = ...
    command_names = ...

    def list_materials(self, ):
        """
        List all locally-stored materials.
        """

    def list_properties(self, name: str):
        """
        List the properties of a locally-stored material.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_data_list import file_data_list as file_data_list_cls
class free_file_data(Command):
    """
    Free file-data.
    
    Parameters
    ----------
        file_data_list : typing.List[str]
            File-data to delete.
    
    """

    fluent_name = "free-file-data"

    argument_names = \
        ['file_data_list']

    file_data_list: file_data_list_cls = file_data_list_cls
    """
    file_data_list argument of free_file_data.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_1 import file_name as file_name_cls
from .surfaces import surfaces as surfaces_cls
from .structural_analysis import structural_analysis as structural_analysis_cls
from .write_loads import write_loads as write_loads_cls
from .loads import loads as loads_cls
from .cell_func_domain_export import cell_func_domain_export as cell_func_domain_export_cls
class patran_neutral(Command):
    """
    Write a PATRAN neutral file.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
        surfaces : typing.List[str]
            Select surface.
        structural_analysis : bool
            'structural_analysis' child.
        write_loads : bool
            'write_loads' child.
        loads : typing.List[str]
            'loads' child.
        cell_func_domain_export : typing.List[str]
            'cell_func_domain_export' child.
    
    """

    fluent_name = "patran-neutral"

    argument_names = \
        ['file_name', 'surfaces', 'structural_analysis', 'write_loads',
         'loads', 'cell_func_domain_export']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of patran_neutral.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces argument of patran_neutral.
    """
    structural_analysis: structural_analysis_cls = structural_analysis_cls
    """
    structural_analysis argument of patran_neutral.
    """
    write_loads: write_loads_cls = write_loads_cls
    """
    write_loads argument of patran_neutral.
    """
    loads: loads_cls = loads_cls
    """
    loads argument of patran_neutral.
    """
    cell_func_domain_export: cell_func_domain_export_cls = cell_func_domain_export_cls
    """
    cell_func_domain_export argument of patran_neutral.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_2 import name as name_cls
from .register import register as register_cls
from .frequency_2 import frequency as frequency_cls
from .active_1 import active as active_cls
from .verbosity_9 import verbosity as verbosity_cls
from .monitor_1 import monitor as monitor_cls
class register_based_child(Group):
    """
    'child_object_type' of register_based.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'register', 'frequency', 'active', 'verbosity', 'monitor']

    name: name_cls = name_cls
    """
    name child of register_based_child.
    """
    register: register_cls = register_cls
    """
    register child of register_based_child.
    """
    frequency: frequency_cls = frequency_cls
    """
    frequency child of register_based_child.
    """
    active: active_cls = active_cls
    """
    active child of register_based_child.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of register_based_child.
    """
    monitor: monitor_cls = monitor_cls
    """
    monitor child of register_based_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .domain import domain as domain_cls
from .all_boundary_zones import all_boundary_zones as all_boundary_zones_cls
from .zones_1 import zones as zones_cls
from .physics_1 import physics as physics_cls
from .write_to_file_1 import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
class electric_current(Command):
    """
    Print electric current rate at boundaries.
    
    Parameters
    ----------
        domain : str
            'domain' child.
        all_boundary_zones : bool
            Select all the boundary/interior zones.
        zones : typing.List[str]
            Enter zone name list.
        physics : typing.List[str]
            'physics' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
    
    """

    fluent_name = "electric-current"

    argument_names = \
        ['domain', 'all_boundary_zones', 'zones', 'physics', 'write_to_file',
         'file_name', 'append_data']

    domain: domain_cls = domain_cls
    """
    domain argument of electric_current.
    """
    all_boundary_zones: all_boundary_zones_cls = all_boundary_zones_cls
    """
    all_boundary_zones argument of electric_current.
    """
    zones: zones_cls = zones_cls
    """
    zones argument of electric_current.
    """
    physics: physics_cls = physics_cls
    """
    physics argument of electric_current.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of electric_current.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of electric_current.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of electric_current.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .x import x as x_cls
from .y import y as y_cls
from .z import z as z_cls
class r(Group):
    """
    'r' child.
    """

    fluent_name = "r"

    child_names = \
        ['x', 'y', 'z']

    x: x_cls = x_cls
    """
    x child of r.
    """
    y: y_cls = y_cls
    """
    y child of r.
    """
    z: z_cls = z_cls
    """
    z child of r.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .discrete_phase import discrete_phase as discrete_phase_cls
from .energy import energy as energy_cls
from .multiphase import multiphase as multiphase_cls
from .viscous import viscous as viscous_cls
from .optics import optics as optics_cls
from .virtual_blade_model import virtual_blade_model as virtual_blade_model_cls
class models(Group):
    """
    'models' child.
    """

    fluent_name = "models"

    child_names = \
        ['discrete_phase', 'energy', 'multiphase', 'viscous', 'optics',
         'virtual_blade_model']

    discrete_phase: discrete_phase_cls = discrete_phase_cls
    """
    discrete_phase child of models.
    """
    energy: energy_cls = energy_cls
    """
    energy child of models.
    """
    multiphase: multiphase_cls = multiphase_cls
    """
    multiphase child of models.
    """
    viscous: viscous_cls = viscous_cls
    """
    viscous child of models.
    """
    optics: optics_cls = optics_cls
    """
    optics child of models.
    """
    virtual_blade_model: virtual_blade_model_cls = virtual_blade_model_cls
    """
    virtual_blade_model child of models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .iter_count_1 import iter_count as iter_count_cls
from .explicit_urf import explicit_urf as explicit_urf_cls
from .reference_frame_1 import reference_frame as reference_frame_cls
from .initial_pressure import initial_pressure as initial_pressure_cls
from .external_aero import external_aero as external_aero_cls
from .const_velocity import const_velocity as const_velocity_cls
class general_settings(Group):
    """
    Enter the general settings menu.
    """

    fluent_name = "general-settings"

    child_names = \
        ['iter_count', 'explicit_urf', 'reference_frame', 'initial_pressure',
         'external_aero', 'const_velocity']

    iter_count: iter_count_cls = iter_count_cls
    """
    iter_count child of general_settings.
    """
    explicit_urf: explicit_urf_cls = explicit_urf_cls
    """
    explicit_urf child of general_settings.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of general_settings.
    """
    initial_pressure: initial_pressure_cls = initial_pressure_cls
    """
    initial_pressure child of general_settings.
    """
    external_aero: external_aero_cls = external_aero_cls
    """
    external_aero child of general_settings.
    """
    const_velocity: const_velocity_cls = const_velocity_cls
    """
    const_velocity child of general_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_type import report_type as report_type_cls
from .thread_id_list import thread_id_list as thread_id_list_cls
from .domain import domain as domain_cls
from .cell_function_1 import cell_function as cell_function_cls
from .current_domain import current_domain as current_domain_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls
class volume_integrals(Command):
    """
    Create a volume integral report.
    
    Parameters
    ----------
        report_type : str
            'report_type' child.
        thread_id_list : typing.List[str]
            'thread_id_list' child.
        domain : str
            'domain' child.
        cell_function : str
            'cell_function' child.
        current_domain : str
            'current_domain' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "volume-integrals"

    argument_names = \
        ['report_type', 'thread_id_list', 'domain', 'cell_function',
         'current_domain', 'write_to_file', 'file_name', 'append_data',
         'overwrite']

    report_type: report_type_cls = report_type_cls
    """
    report_type argument of volume_integrals.
    """
    thread_id_list: thread_id_list_cls = thread_id_list_cls
    """
    thread_id_list argument of volume_integrals.
    """
    domain: domain_cls = domain_cls
    """
    domain argument of volume_integrals.
    """
    cell_function: cell_function_cls = cell_function_cls
    """
    cell_function argument of volume_integrals.
    """
    current_domain: current_domain_cls = current_domain_cls
    """
    current_domain argument of volume_integrals.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of volume_integrals.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of volume_integrals.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of volume_integrals.
    """
    overwrite: overwrite_cls = overwrite_cls
    """
    overwrite argument of volume_integrals.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class rendering_options:
    fluent_name = ...
    child_names = ...
    animation_option = ...
    auto_spin = ...
    color_map_alignment = ...
    double_buffering = ...
    face_displacement = ...
    hidden_surface_method = ...
    hidden_surfaces = ...
    front_faces_transparent = ...
    show_colormap = ...
    command_names = ...

    def device_info(self, ):
        """
        List information for the graphics device.
        """

    def driver(self, driver_name: str):
        """
        Change the current graphics driver.
        
        Parameters
        ----------
            driver_name : str
                'driver_name' child.
        
        """

    def set_rendering_options(self, ):
        """
        Set the rendering options.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties import list_properties as list_properties_cls
from .injection_hole_child import injection_hole_child

class injection_hole(ListObject[injection_hole_child]):
    """
    'injection_hole' child.
    """

    fluent_name = "injection-hole"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of injection_hole.
    """
    child_object_type: injection_hole_child = injection_hole_child
    """
    child_object_type of injection_hole.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .convergence_reports_child import convergence_reports_child

class convergence_reports(NamedObject[convergence_reports_child], _CreatableNamedObjectMixin[convergence_reports_child]):
    """
    'convergence_reports' child.
    """

    fluent_name = "convergence-reports"

    child_object_type: convergence_reports_child = convergence_reports_child
    """
    child_object_type of convergence_reports.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .ntgk_model_parameter import ntgk_model_parameter as ntgk_model_parameter_cls
from .ecm_model_parameter import ecm_model_parameter as ecm_model_parameter_cls
from .user_defined_echem_model import user_defined_echem_model as user_defined_echem_model_cls
from .p2d_bv_rate import p2d_bv_rate as p2d_bv_rate_cls
from .p2d_postprocessing import p2d_postprocessing as p2d_postprocessing_cls
from .p2d_porosity_p import p2d_porosity_p as p2d_porosity_p_cls
from .p2d_porosity_n import p2d_porosity_n as p2d_porosity_n_cls
class udf_hooks(Group):
    """
    'udf_hooks' child.
    """

    fluent_name = "udf-hooks"

    child_names = \
        ['ntgk_model_parameter', 'ecm_model_parameter',
         'user_defined_echem_model', 'p2d_bv_rate', 'p2d_postprocessing',
         'p2d_porosity_p', 'p2d_porosity_n']

    ntgk_model_parameter: ntgk_model_parameter_cls = ntgk_model_parameter_cls
    """
    ntgk_model_parameter child of udf_hooks.
    """
    ecm_model_parameter: ecm_model_parameter_cls = ecm_model_parameter_cls
    """
    ecm_model_parameter child of udf_hooks.
    """
    user_defined_echem_model: user_defined_echem_model_cls = user_defined_echem_model_cls
    """
    user_defined_echem_model child of udf_hooks.
    """
    p2d_bv_rate: p2d_bv_rate_cls = p2d_bv_rate_cls
    """
    p2d_bv_rate child of udf_hooks.
    """
    p2d_postprocessing: p2d_postprocessing_cls = p2d_postprocessing_cls
    """
    p2d_postprocessing child of udf_hooks.
    """
    p2d_porosity_p: p2d_porosity_p_cls = p2d_porosity_p_cls
    """
    p2d_porosity_p child of udf_hooks.
    """
    p2d_porosity_n: p2d_porosity_n_cls = p2d_porosity_n_cls
    """
    p2d_porosity_n child of udf_hooks.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .hybrid_model import hybrid_model as hybrid_model_cls
from .user_defined_1 import user_defined as user_defined_cls
from .update_interval_k_omega import update_interval_k_omega as update_interval_k_omega_cls
from .les_subgrid_scale_model import les_subgrid_scale_model as les_subgrid_scale_model_cls
from .les_subgrid_dynamic_fvar import les_subgrid_dynamic_fvar as les_subgrid_dynamic_fvar_cls
class sbes_options(Group):
    """
    'sbes_options' child.
    """

    fluent_name = "sbes-options"

    child_names = \
        ['hybrid_model', 'user_defined', 'update_interval_k_omega',
         'les_subgrid_scale_model', 'les_subgrid_dynamic_fvar']

    hybrid_model: hybrid_model_cls = hybrid_model_cls
    """
    hybrid_model child of sbes_options.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of sbes_options.
    """
    update_interval_k_omega: update_interval_k_omega_cls = update_interval_k_omega_cls
    """
    update_interval_k_omega child of sbes_options.
    """
    les_subgrid_scale_model: les_subgrid_scale_model_cls = les_subgrid_scale_model_cls
    """
    les_subgrid_scale_model child of sbes_options.
    """
    les_subgrid_dynamic_fvar: les_subgrid_dynamic_fvar_cls = les_subgrid_dynamic_fvar_cls
    """
    les_subgrid_dynamic_fvar child of sbes_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class n_save(Integer):
    """
    Set number of residuals to be saved with data.
    History is automatically compacted when buffer becomes full.
    """

    fluent_name = "n-save"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class bodies_child:
    fluent_name = ...
    child_names = ...
    name = ...
    faces = ...
    command_names = ...

    def list_properties(self, ):
        """
        'list_properties' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thread_number_method import thread_number_method as thread_number_method_cls
from .fixed_thread_number import fixed_thread_number as fixed_thread_number_cls
class thread_number_control(Group):
    """
    Thread number control.
    """

    fluent_name = "thread-number-control"

    child_names = \
        ['thread_number_method', 'fixed_thread_number']

    thread_number_method: thread_number_method_cls = thread_number_method_cls
    """
    thread_number_method child of thread_number_control.
    """
    fixed_thread_number: fixed_thread_number_cls = fixed_thread_number_cls
    """
    fixed_thread_number child of thread_number_control.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thermal_effects_1 import thermal_effects as thermal_effects_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['thermal_effects']

    thermal_effects: thermal_effects_cls = thermal_effects_cls
    """
    thermal_effects child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class old_default_of_volume_fraction_smoothing(Boolean):
    """
    Revert to the old default of volume fraction smoothings for surface tension.
    """

    fluent_name = "old-default-of-volume-fraction-smoothing"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .plot_window import plot_window as plot_window_cls
from .old_props import old_props as old_props_cls
from .frequency import frequency as frequency_cls
from .flow_frequency import flow_frequency as flow_frequency_cls
from .frequency_of import frequency_of as frequency_of_cls
from .report_defs import report_defs as report_defs_cls
from .print_1 import print as print_cls
from .title import title as title_cls
from .x_label import x_label as x_label_cls
from .y_label import y_label as y_label_cls
from .active import active as active_cls
from .plot_instantaneous_values import plot_instantaneous_values as plot_instantaneous_values_cls
class report_plots_child(Group):
    """
    'child_object_type' of report_plots.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'plot_window', 'old_props', 'frequency', 'flow_frequency',
         'frequency_of', 'report_defs', 'print', 'title', 'x_label',
         'y_label', 'active', 'plot_instantaneous_values']

    name: name_cls = name_cls
    """
    name child of report_plots_child.
    """
    plot_window: plot_window_cls = plot_window_cls
    """
    plot_window child of report_plots_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of report_plots_child.
    """
    frequency: frequency_cls = frequency_cls
    """
    frequency child of report_plots_child.
    """
    flow_frequency: flow_frequency_cls = flow_frequency_cls
    """
    flow_frequency child of report_plots_child.
    """
    frequency_of: frequency_of_cls = frequency_of_cls
    """
    frequency_of child of report_plots_child.
    """
    report_defs: report_defs_cls = report_defs_cls
    """
    report_defs child of report_plots_child.
    """
    print: print_cls = print_cls
    """
    print child of report_plots_child.
    """
    title: title_cls = title_cls
    """
    title child of report_plots_child.
    """
    x_label: x_label_cls = x_label_cls
    """
    x_label child of report_plots_child.
    """
    y_label: y_label_cls = y_label_cls
    """
    y_label child of report_plots_child.
    """
    active: active_cls = active_cls
    """
    active child of report_plots_child.
    """
    plot_instantaneous_values: plot_instantaneous_values_cls = plot_instantaneous_values_cls
    """
    plot_instantaneous_values child of report_plots_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .field_1 import field as field_cls
from .surfaces_4 import surfaces as surfaces_cls
from .zones_4 import zones as zones_cls
from .min_3 import min as min_cls
from .max_3 import max as max_cls
from .iso_values import iso_values as iso_values_cls
from .display_3 import display as display_cls
class iso_surface_child(Group):
    """
    'child_object_type' of iso_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'surfaces', 'zones', 'min', 'max', 'iso_values']

    name: name_cls = name_cls
    """
    name child of iso_surface_child.
    """
    field: field_cls = field_cls
    """
    field child of iso_surface_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of iso_surface_child.
    """
    zones: zones_cls = zones_cls
    """
    zones child of iso_surface_child.
    """
    min: min_cls = min_cls
    """
    min child of iso_surface_child.
    """
    max: max_cls = max_cls
    """
    max child of iso_surface_child.
    """
    iso_values: iso_values_cls = iso_values_cls
    """
    iso_values child of iso_surface_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of iso_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geometry_1 import geometry as geometry_cls
from .physics import physics as physics_cls
from .field import field as field_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .report_type import report_type as report_type_cls
from .phase_25 import phase as phase_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .old_props import old_props as old_props_cls
from .zone_names import zone_names as zone_names_cls
from .expr_list import expr_list as expr_list_cls
from .zone_list import zone_list as zone_list_cls
class volume_child(Group):
    """
    'child_object_type' of volume.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geometry', 'physics', 'field', 'retain_instantaneous_values',
         'report_type', 'phase', 'average_over', 'per_zone', 'old_props',
         'zone_names', 'expr_list', 'zone_list']

    geometry: geometry_cls = geometry_cls
    """
    geometry child of volume_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of volume_child.
    """
    field: field_cls = field_cls
    """
    field child of volume_child.
    """
    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of volume_child.
    """
    report_type: report_type_cls = report_type_cls
    """
    report_type child of volume_child.
    """
    phase: phase_cls = phase_cls
    """
    phase child of volume_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of volume_child.
    """
    per_zone: per_zone_cls = per_zone_cls
    """
    per_zone child of volume_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of volume_child.
    """
    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names child of volume_child.
    """
    expr_list: expr_list_cls = expr_list_cls
    """
    expr_list child of volume_child.
    """
    zone_list: zone_list_cls = zone_list_cls
    """
    zone_list child of volume_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .x_component import x_component as x_component_cls
from .y_component import y_component as y_component_cls
from .z_component import z_component as z_component_cls
class custom_vectors_child(Group):
    """
    'child_object_type' of custom_vectors.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'x_component', 'y_component', 'z_component']

    name: name_cls = name_cls
    """
    name child of custom_vectors_child.
    """
    x_component: x_component_cls = x_component_cls
    """
    x_component child of custom_vectors_child.
    """
    y_component: y_component_cls = y_component_cls
    """
    y_component child of custom_vectors_child.
    """
    z_component: z_component_cls = z_component_cls
    """
    z_component child of custom_vectors_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_5 import enable as enable_cls
from .robustness_enhancement import robustness_enhancement as robustness_enhancement_cls
from .nasa9_enhancement import nasa9_enhancement as nasa9_enhancement_cls
from .set_verbosity import set_verbosity as set_verbosity_cls
from .translational_vibrational_energy_relaxation import translational_vibrational_energy_relaxation as translational_vibrational_energy_relaxation_cls
class two_temperature(Group):
    """
    Define two-temperature model menu.
    """

    fluent_name = "two-temperature"

    child_names = \
        ['enable', 'robustness_enhancement', 'nasa9_enhancement',
         'set_verbosity', 'translational_vibrational_energy_relaxation']

    enable: enable_cls = enable_cls
    """
    enable child of two_temperature.
    """
    robustness_enhancement: robustness_enhancement_cls = robustness_enhancement_cls
    """
    robustness_enhancement child of two_temperature.
    """
    nasa9_enhancement: nasa9_enhancement_cls = nasa9_enhancement_cls
    """
    nasa9_enhancement child of two_temperature.
    """
    set_verbosity: set_verbosity_cls = set_verbosity_cls
    """
    set_verbosity child of two_temperature.
    """
    translational_vibrational_energy_relaxation: translational_vibrational_energy_relaxation_cls = translational_vibrational_energy_relaxation_cls
    """
    translational_vibrational_energy_relaxation child of two_temperature.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .database_type import database_type as database_type_cls
from .copy_by_formula import copy_by_formula as copy_by_formula_cls
from .copy_by_name import copy_by_name as copy_by_name_cls
from .list_materials import list_materials as list_materials_cls
from .list_properties_2 import list_properties as list_properties_cls
class database(Group):
    """
    'database' child.
    """

    fluent_name = "database"

    child_names = \
        ['database_type']

    database_type: database_type_cls = database_type_cls
    """
    database_type child of database.
    """
    command_names = \
        ['copy_by_formula', 'copy_by_name', 'list_materials',
         'list_properties']

    copy_by_formula: copy_by_formula_cls = copy_by_formula_cls
    """
    copy_by_formula command of database.
    """
    copy_by_name: copy_by_name_cls = copy_by_name_cls
    """
    copy_by_name command of database.
    """
    list_materials: list_materials_cls = list_materials_cls
    """
    list_materials command of database.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of database.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enalbled import enalbled as enalbled_cls
from .user_defined_timestep import user_defined_timestep as user_defined_timestep_cls
from .desired_cfl import desired_cfl as desired_cfl_cls
from .time_end import time_end as time_end_cls
from .initial_time_step import initial_time_step as initial_time_step_cls
from .max_fixed_time_step import max_fixed_time_step as max_fixed_time_step_cls
from .update_interval_time_step_size import update_interval_time_step_size as update_interval_time_step_size_cls
from .min_time_step import min_time_step as min_time_step_cls
from .max_time_step import max_time_step as max_time_step_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls
class cfl_based_adaptive_time_stepping(Group):
    """
    'cfl_based_adaptive_time_stepping' child.
    """

    fluent_name = "cfl-based-adaptive-time-stepping"

    child_names = \
        ['enalbled', 'user_defined_timestep', 'desired_cfl', 'time_end',
         'initial_time_step', 'max_fixed_time_step',
         'update_interval_time_step_size', 'min_time_step', 'max_time_step',
         'min_step_change_factor', 'max_step_change_factor']

    enalbled: enalbled_cls = enalbled_cls
    """
    enalbled child of cfl_based_adaptive_time_stepping.
    """
    user_defined_timestep: user_defined_timestep_cls = user_defined_timestep_cls
    """
    user_defined_timestep child of cfl_based_adaptive_time_stepping.
    """
    desired_cfl: desired_cfl_cls = desired_cfl_cls
    """
    desired_cfl child of cfl_based_adaptive_time_stepping.
    """
    time_end: time_end_cls = time_end_cls
    """
    time_end child of cfl_based_adaptive_time_stepping.
    """
    initial_time_step: initial_time_step_cls = initial_time_step_cls
    """
    initial_time_step child of cfl_based_adaptive_time_stepping.
    """
    max_fixed_time_step: max_fixed_time_step_cls = max_fixed_time_step_cls
    """
    max_fixed_time_step child of cfl_based_adaptive_time_stepping.
    """
    update_interval_time_step_size: update_interval_time_step_size_cls = update_interval_time_step_size_cls
    """
    update_interval_time_step_size child of cfl_based_adaptive_time_stepping.
    """
    min_time_step: min_time_step_cls = min_time_step_cls
    """
    min_time_step child of cfl_based_adaptive_time_stepping.
    """
    max_time_step: max_time_step_cls = max_time_step_cls
    """
    max_time_step child of cfl_based_adaptive_time_stepping.
    """
    min_step_change_factor: min_step_change_factor_cls = min_step_change_factor_cls
    """
    min_step_change_factor child of cfl_based_adaptive_time_stepping.
    """
    max_step_change_factor: max_step_change_factor_cls = max_step_change_factor_cls
    """
    max_step_change_factor child of cfl_based_adaptive_time_stepping.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .proc_statistics import proc_statistics as proc_statistics_cls
from .sys_statistics import sys_statistics as sys_statistics_cls
from .gpgpu_statistics import gpgpu_statistics as gpgpu_statistics_cls
from .time_statistics import time_statistics as time_statistics_cls
class system(Group):
    """
    'system' child.
    """

    fluent_name = "system"

    command_names = \
        ['proc_statistics', 'sys_statistics', 'gpgpu_statistics',
         'time_statistics']

    proc_statistics: proc_statistics_cls = proc_statistics_cls
    """
    proc_statistics command of system.
    """
    sys_statistics: sys_statistics_cls = sys_statistics_cls
    """
    sys_statistics command of system.
    """
    gpgpu_statistics: gpgpu_statistics_cls = gpgpu_statistics_cls
    """
    gpgpu_statistics command of system.
    """
    time_statistics: time_statistics_cls = time_statistics_cls
    """
    time_statistics command of system.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class pathline_child:
    fluent_name = ...
    child_names = ...
    name = ...
    uid = ...
    options = ...
    range = ...
    style_attribute = ...
    accuracy_control = ...
    plot = ...
    step = ...
    skip = ...
    coarsen = ...
    onzone = ...
    onphysics = ...
    field = ...
    surfaces_list = ...
    velocity_domain = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    axes = ...
    curves = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class law_of_the_wall(String, _HasAllowedValuesMixin):
    """
    'law_of_the_wall' child.
    """

    fluent_name = "law-of-the-wall"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .hide_environment_keep_effects import hide_environment_keep_effects as hide_environment_keep_effects_cls
from .environment_image import environment_image as environment_image_cls
from .latitude_1 import latitude as latitude_cls
from .longitude_1 import longitude as longitude_cls
from .view_zoom import view_zoom as view_zoom_cls
from .show_backplate import show_backplate as show_backplate_cls
from .backplate_color import backplate_color as backplate_color_cls
from .backplate_image import backplate_image as backplate_image_cls
class background(Group):
    """
    Enter the menu for background options.
    """

    fluent_name = "background"

    child_names = \
        ['hide_environment_keep_effects', 'environment_image', 'latitude',
         'longitude', 'view_zoom', 'show_backplate', 'backplate_color',
         'backplate_image']

    hide_environment_keep_effects: hide_environment_keep_effects_cls = hide_environment_keep_effects_cls
    """
    hide_environment_keep_effects child of background.
    """
    environment_image: environment_image_cls = environment_image_cls
    """
    environment_image child of background.
    """
    latitude: latitude_cls = latitude_cls
    """
    latitude child of background.
    """
    longitude: longitude_cls = longitude_cls
    """
    longitude child of background.
    """
    view_zoom: view_zoom_cls = view_zoom_cls
    """
    view_zoom child of background.
    """
    show_backplate: show_backplate_cls = show_backplate_cls
    """
    show_backplate child of background.
    """
    backplate_color: backplate_color_cls = backplate_color_cls
    """
    backplate_color child of background.
    """
    backplate_image: backplate_image_cls = backplate_image_cls
    """
    backplate_image child of background.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class contact_solution_controls:
    fluent_name = ...
    child_names = ...
    solution_stabilization = ...
    verbosity = ...
    parameters = ...
    spatial = ...
    transient = ...
    amg = ...
    models = ...
    methods = ...
    miscellaneous = ...
    command_names = ...

    def set_settings_to_default(self, ):
        """
        Set contact solution stabilization to default.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_12 import enabled as enabled_cls
from .calendar_time import calendar_time as calendar_time_cls
from .cycle_number import cycle_number as cycle_number_cls
from .operation_temperature import operation_temperature as operation_temperature_cls
from .calendar_life_params import calendar_life_params as calendar_life_params_cls
from .cycle_life_table import cycle_life_table as cycle_life_table_cls
class life_model(Group):
    """
    'life_model' child.
    """

    fluent_name = "life-model"

    child_names = \
        ['enabled', 'calendar_time', 'cycle_number', 'operation_temperature',
         'calendar_life_params', 'cycle_life_table']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of life_model.
    """
    calendar_time: calendar_time_cls = calendar_time_cls
    """
    calendar_time child of life_model.
    """
    cycle_number: cycle_number_cls = cycle_number_cls
    """
    cycle_number child of life_model.
    """
    operation_temperature: operation_temperature_cls = operation_temperature_cls
    """
    operation_temperature child of life_model.
    """
    calendar_life_params: calendar_life_params_cls = calendar_life_params_cls
    """
    calendar_life_params child of life_model.
    """
    cycle_life_table: cycle_life_table_cls = cycle_life_table_cls
    """
    cycle_life_table child of life_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .end_of_timestep import end_of_timestep as end_of_timestep_cls
class interrupt(Command):
    """
    Interrupt the iterations.
    
    Parameters
    ----------
        end_of_timestep : bool
            'end_of_timestep' child.
    
    """

    fluent_name = "interrupt"

    argument_names = \
        ['end_of_timestep']

    end_of_timestep: end_of_timestep_cls = end_of_timestep_cls
    """
    end_of_timestep argument of interrupt.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enhanced_method_enabled import enhanced_method_enabled as enhanced_method_enabled_cls
from .support_for_std_track_data_read_enabled import support_for_std_track_data_read_enabled as support_for_std_track_data_read_enabled_cls
from .overset_robustness_level import overset_robustness_level as overset_robustness_level_cls
from .legacy_method_enabled import legacy_method_enabled as legacy_method_enabled_cls
class particle_relocation(Group):
    """
    Main menu holding information options to control relocating particles during case file reading or remeshing/adaption.
    """

    fluent_name = "particle-relocation"

    child_names = \
        ['enhanced_method_enabled', 'support_for_std_track_data_read_enabled',
         'overset_robustness_level', 'legacy_method_enabled']

    enhanced_method_enabled: enhanced_method_enabled_cls = enhanced_method_enabled_cls
    """
    enhanced_method_enabled child of particle_relocation.
    """
    support_for_std_track_data_read_enabled: support_for_std_track_data_read_enabled_cls = support_for_std_track_data_read_enabled_cls
    """
    support_for_std_track_data_read_enabled child of particle_relocation.
    """
    overset_robustness_level: overset_robustness_level_cls = overset_robustness_level_cls
    """
    overset_robustness_level child of particle_relocation.
    """
    legacy_method_enabled: legacy_method_enabled_cls = legacy_method_enabled_cls
    """
    legacy_method_enabled child of particle_relocation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class beta_factor_omega_equation(Real):
    """
    Specify the beta factor in the omega equation.
    """

    fluent_name = "beta-factor-omega-equation"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .initial_fraction_of_bridges_in_coal_lattice import initial_fraction_of_bridges_in_coal_lattice as initial_fraction_of_bridges_in_coal_lattice_cls
from .initial_fraction_of_char_bridges import initial_fraction_of_char_bridges as initial_fraction_of_char_bridges_cls
from .lattice_coordination_number import lattice_coordination_number as lattice_coordination_number_cls
from .cluster_molecular_weight import cluster_molecular_weight as cluster_molecular_weight_cls
from .side_chain_molecular_weight import side_chain_molecular_weight as side_chain_molecular_weight_cls
class cpd_model(Group):
    """
    'cpd_model' child.
    """

    fluent_name = "cpd-model"

    child_names = \
        ['initial_fraction_of_bridges_in_coal_lattice',
         'initial_fraction_of_char_bridges', 'lattice_coordination_number',
         'cluster_molecular_weight', 'side_chain_molecular_weight']

    initial_fraction_of_bridges_in_coal_lattice: initial_fraction_of_bridges_in_coal_lattice_cls = initial_fraction_of_bridges_in_coal_lattice_cls
    """
    initial_fraction_of_bridges_in_coal_lattice child of cpd_model.
    """
    initial_fraction_of_char_bridges: initial_fraction_of_char_bridges_cls = initial_fraction_of_char_bridges_cls
    """
    initial_fraction_of_char_bridges child of cpd_model.
    """
    lattice_coordination_number: lattice_coordination_number_cls = lattice_coordination_number_cls
    """
    lattice_coordination_number child of cpd_model.
    """
    cluster_molecular_weight: cluster_molecular_weight_cls = cluster_molecular_weight_cls
    """
    cluster_molecular_weight child of cpd_model.
    """
    side_chain_molecular_weight: side_chain_molecular_weight_cls = side_chain_molecular_weight_cls
    """
    side_chain_molecular_weight child of cpd_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cell_zone_list import cell_zone_list as cell_zone_list_cls
class activate_cell_zone(Command):
    """
    Activate a cell thread.
    
    Parameters
    ----------
        cell_zone_list : typing.List[str]
            'cell_zone_list' child.
    
    """

    fluent_name = "activate-cell-zone"

    argument_names = \
        ['cell_zone_list']

    cell_zone_list: cell_zone_list_cls = cell_zone_list_cls
    """
    cell_zone_list argument of activate_cell_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .reference_pressure import reference_pressure as reference_pressure_cls
from .reference_density import reference_density as reference_density_cls
from .reference_bulk_modulus import reference_bulk_modulus as reference_bulk_modulus_cls
from .density_exponent import density_exponent as density_exponent_cls
from .maximum_density_ratio import maximum_density_ratio as maximum_density_ratio_cls
from .minimum_density_ratio import minimum_density_ratio as minimum_density_ratio_cls
class compressible_liquid(Group):
    """
    'compressible_liquid' child.
    """

    fluent_name = "compressible-liquid"

    child_names = \
        ['reference_pressure', 'reference_density', 'reference_bulk_modulus',
         'density_exponent', 'maximum_density_ratio',
         'minimum_density_ratio']

    reference_pressure: reference_pressure_cls = reference_pressure_cls
    """
    reference_pressure child of compressible_liquid.
    """
    reference_density: reference_density_cls = reference_density_cls
    """
    reference_density child of compressible_liquid.
    """
    reference_bulk_modulus: reference_bulk_modulus_cls = reference_bulk_modulus_cls
    """
    reference_bulk_modulus child of compressible_liquid.
    """
    density_exponent: density_exponent_cls = density_exponent_cls
    """
    density_exponent child of compressible_liquid.
    """
    maximum_density_ratio: maximum_density_ratio_cls = maximum_density_ratio_cls
    """
    maximum_density_ratio child of compressible_liquid.
    """
    minimum_density_ratio: minimum_density_ratio_cls = minimum_density_ratio_cls
    """
    minimum_density_ratio child of compressible_liquid.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .alpha import alpha as alpha_cls
from .dm import dm as dm_cls
from .c2 import c2 as c2_cls
from .thermal_ctk import thermal_ctk as thermal_ctk_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .v_absp import v_absp as v_absp_cls
from .ir_absp import ir_absp as ir_absp_cls
from .ir_trans import ir_trans as ir_trans_cls
from .v_trans import v_trans as v_trans_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls
from .jump_adhesion import jump_adhesion as jump_adhesion_cls
from .adhesion_constrained import adhesion_constrained as adhesion_constrained_cls
from .adhesion_angle import adhesion_angle as adhesion_angle_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'alpha', 'dm', 'c2',
         'thermal_ctk', 'solar_fluxes', 'v_absp', 'ir_absp', 'ir_trans',
         'v_trans', 'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj',
         'dpm_bc_udf', 'strength', 'jump_adhesion', 'adhesion_constrained',
         'adhesion_angle', 'x_displacement_type', 'x_displacement_value',
         'y_displacement_type', 'y_displacement_value', 'z_displacement_type',
         'z_displacement_value']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = porous_jump_turb_wall_treatment_cls
    """
    porous_jump_turb_wall_treatment child of phase_child.
    """
    alpha: alpha_cls = alpha_cls
    """
    alpha child of phase_child.
    """
    dm: dm_cls = dm_cls
    """
    dm child of phase_child.
    """
    c2: c2_cls = c2_cls
    """
    c2 child of phase_child.
    """
    thermal_ctk: thermal_ctk_cls = thermal_ctk_cls
    """
    thermal_ctk child of phase_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of phase_child.
    """
    v_absp: v_absp_cls = v_absp_cls
    """
    v_absp child of phase_child.
    """
    ir_absp: ir_absp_cls = ir_absp_cls
    """
    ir_absp child of phase_child.
    """
    ir_trans: ir_trans_cls = ir_trans_cls
    """
    ir_trans child of phase_child.
    """
    v_trans: v_trans_cls = v_trans_cls
    """
    v_trans child of phase_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of phase_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of phase_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of phase_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of phase_child.
    """
    jump_adhesion: jump_adhesion_cls = jump_adhesion_cls
    """
    jump_adhesion child of phase_child.
    """
    adhesion_constrained: adhesion_constrained_cls = adhesion_constrained_cls
    """
    adhesion_constrained child of phase_child.
    """
    adhesion_angle: adhesion_angle_cls = adhesion_angle_cls
    """
    adhesion_angle child of phase_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of phase_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of phase_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of phase_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of phase_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of phase_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_beeam_direction_from_solar_load_model_settings(Boolean, _HasAllowedValuesMixin):
    """
    Use Beam Direction from Solar Load Model Settings.
    """

    fluent_name = "use-beeam-direction-from-solar-load-model-settings"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_3 import delete as delete_cls
from .overlapping_percentage_threshold import overlapping_percentage_threshold as overlapping_percentage_threshold_cls
class delete_interfaces_with_small_overlap(Command):
    """
    Delete mesh interfaces that have an area percentage under a specified value.
    
    Parameters
    ----------
        delete : bool
            'delete' child.
        overlapping_percentage_threshold : real
            'overlapping_percentage_threshold' child.
    
    """

    fluent_name = "delete-interfaces-with-small-overlap"

    argument_names = \
        ['delete', 'overlapping_percentage_threshold']

    delete: delete_cls = delete_cls
    """
    delete argument of delete_interfaces_with_small_overlap.
    """
    overlapping_percentage_threshold: overlapping_percentage_threshold_cls = overlapping_percentage_threshold_cls
    """
    overlapping_percentage_threshold argument of delete_interfaces_with_small_overlap.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .min_diam import min_diam as min_diam_cls
from .max_diam import max_diam as max_diam_cls
from .mean_diam import mean_diam as mean_diam_cls
from .spread import spread as spread_cls
from .number_of_diameters import number_of_diameters as number_of_diameters_cls
class rosin_rammler(Group):
    """
    'rosin_rammler' child.
    """

    fluent_name = "rosin-rammler"

    child_names = \
        ['min_diam', 'max_diam', 'mean_diam', 'spread', 'number_of_diameters']

    min_diam: min_diam_cls = min_diam_cls
    """
    min_diam child of rosin_rammler.
    """
    max_diam: max_diam_cls = max_diam_cls
    """
    max_diam child of rosin_rammler.
    """
    mean_diam: mean_diam_cls = mean_diam_cls
    """
    mean_diam child of rosin_rammler.
    """
    spread: spread_cls = spread_cls
    """
    spread child of rosin_rammler.
    """
    number_of_diameters: number_of_diameters_cls = number_of_diameters_cls
    """
    number_of_diameters child of rosin_rammler.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class clear_particles_from_domain(Command):
    """
    Clear all particles currently in the domain.
    """

    fluent_name = "clear-particles-from-domain"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class merge_small_regions(Boolean):
    """
    'merge_small_regions' child.
    """

    fluent_name = "merge-small-regions?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cathode_pl_zone_list import cathode_pl_zone_list as cathode_pl_zone_list_cls
from .cathode_pl_update import cathode_pl_update as cathode_pl_update_cls
from .cathode_pl_material import cathode_pl_material as cathode_pl_material_cls
from .cathode_pl_porosity import cathode_pl_porosity as cathode_pl_porosity_cls
from .cathode_pl_kr import cathode_pl_kr as cathode_pl_kr_cls
class cathode_pl_zone(Group):
    """
    'cathode_pl_zone' child.
    """

    fluent_name = "cathode-pl-zone"

    child_names = \
        ['cathode_pl_zone_list', 'cathode_pl_update', 'cathode_pl_material',
         'cathode_pl_porosity', 'cathode_pl_kr']

    cathode_pl_zone_list: cathode_pl_zone_list_cls = cathode_pl_zone_list_cls
    """
    cathode_pl_zone_list child of cathode_pl_zone.
    """
    cathode_pl_update: cathode_pl_update_cls = cathode_pl_update_cls
    """
    cathode_pl_update child of cathode_pl_zone.
    """
    cathode_pl_material: cathode_pl_material_cls = cathode_pl_material_cls
    """
    cathode_pl_material child of cathode_pl_zone.
    """
    cathode_pl_porosity: cathode_pl_porosity_cls = cathode_pl_porosity_cls
    """
    cathode_pl_porosity child of cathode_pl_zone.
    """
    cathode_pl_kr: cathode_pl_kr_cls = cathode_pl_kr_cls
    """
    cathode_pl_kr child of cathode_pl_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .filepath import filepath as filepath_cls
from .delete_existing import delete_existing as delete_existing_cls
class import_design_table(Command):
    """
    Import Design Point Table.
    
    Parameters
    ----------
        filepath : str
            'filepath' child.
        delete_existing : bool
            'delete_existing' child.
    
    """

    fluent_name = "import-design-table"

    argument_names = \
        ['filepath', 'delete_existing']

    filepath: filepath_cls = filepath_cls
    """
    filepath argument of import_design_table.
    """
    delete_existing: delete_existing_cls = delete_existing_cls
    """
    delete_existing argument of import_design_table.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cathode_jref(Real):
    """
    Cathode Reference Current Density (A/m2).
    """

    fluent_name = "cathode-jref"

